@@ -1864,8 +1864,8 @@ s_chtml10_start_form_tag(void *pdoc, Node *node)
     char *new_query_string = NULL;
     q = strchr(attr_value, '?');
     if (q) {
-      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_value, 0, post_flag, &new_query_string, CHXJ_TRUE);
-      if (new_hidden_tag) {
+      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_value, 0, post_flag, &new_query_string, CHXJ_TRUE, CHXJ_FALSE);
+      if (new_hidden_tag || new_query_string) {
         *q = 0;
       }
     }
